"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = require("react");
var howler_1 = __importDefault(require("howler"));
/**
 * A hook to get a Howl instance for use with `<Play />`.
 *
 * Recommended when using Rehowl from a function component. If you're
 * using a class component, you'll need to use `<Rehowl />`.
 */
function useHowl(howlOptions) {
    var src = howlOptions.src, sprite = howlOptions.sprite, format = howlOptions.format, html5 = howlOptions.html5, preload = howlOptions.preload, xhrWithCredentials = howlOptions.xhrWithCredentials;
    var _a = react_1.useState(null), howl = _a[0], setHowl = _a[1];
    // Force rerender on load state changes.
    var _b = react_1.useState('unloaded'), setState = _b[1];
    // Force rerender on unlock.
    var _c = react_1.useState(true), setLocked = _c[1];
    var _d = react_1.useState(null), error = _d[0], setError = _d[1];
    react_1.useEffect(function () {
        var newHowl = new howler_1.default.Howl({
            src: src,
            sprite: sprite,
            format: format,
            html5: html5,
            xhrWithCredentials: xhrWithCredentials,
            preload: preload,
            autoplay: false,
            onunlock: function () {
                setLocked(false);
            },
            onload: function () { return setState('loaded'); },
            onloaderror: function (id, message) { return setError({ id: id, message: message }); },
        });
        setHowl(newHowl);
        return function () {
            setHowl(null);
            setState('unloaded');
            setLocked(true);
            setError(null);
            if (!newHowl)
                return;
            newHowl.off();
            newHowl.stop();
            newHowl.unload();
        };
    }, [JSON.stringify(src), JSON.stringify(sprite), JSON.stringify(format), html5, xhrWithCredentials, preload]);
    if (!howl)
        return {
            howl: null,
            error: null,
            state: 'unloaded',
            load: function () { },
        };
    var state = howl.state();
    return {
        howl: howl,
        error: error,
        state: state,
        load: state === 'unloaded'
            ? function () {
                howl && howl.load();
                setState('loading');
            }
            : function () { },
    };
}
exports.default = useHowl;
